@@ -123,11 +123,16 @@ class PCA(object):
         n_components: int, number of PCA components
         mean: [n_atoms, 3] array, mean structure
         eigenvalues: [n_components] array
+        eigenvectors: [n_components, 3*n_atoms] array
         
     """
-    def __init__(self, n_components=None):
+    def __init__(self, n_components=None, procrustes=True):
         self.n_components = n_components
         self._pca = skPCA(n_components=self.n_components)
+        if procrustes:
+            self._fitter = Procrustes()
+        else:
+            self._fitter = None
 
     def fit(self, traj):
         """
@@ -136,7 +141,7 @@ class PCA(object):
         Args:
             traj: [n_frames, n_atoms, 3] numpy array of coordinates.
         """
-        traj = check_dimensions(traj)
+        traj = check_dimensions(traj, ensure_traj=True)
         n_frames = traj.shape[0]
         self.n_atoms = traj.shape[1]
 
@@ -144,11 +149,14 @@ class PCA(object):
             if self.n_components > 1 and self.n_components > min(n_frames, 3 * self.n_atoms):
                 raise ValueError('Error: cannot find {} principal components from a trajectory of {} frames of {} atoms'.format(self.n_components, n_frames, self.n_atoms))
           
-        self._fitter = Procrustes()
-        fitted_traj = self._fitter.fit_transform(traj)
+        if self._fitter is not None:
+            fitted_traj = self._fitter.fit_transform(traj)
+        else:
+            fitted_traj = traj
         self._pca.fit(fitted_traj.reshape((n_frames, -1)))
         self.n_components = self._pca.n_components_
         self.eigenvalues = self._pca.explained_variance_
+        self.eigenvectors = self._pca.components_
         self.mean = self._pca.mean_.reshape((self.n_atoms, 3))
 
     def transform(self, traj):
@@ -162,12 +170,19 @@ class PCA(object):
             An [n_frames, n_components)
         """
         traj = check_dimensions(traj)
+        one_frame = len(traj.shape) == 2
+        if one_frame:
+            traj = traj.reshape((1, -1, 3))
         n_atoms = traj.shape[1]
         if n_atoms != self.n_atoms:
             raise ValueError('Error: trajectory has {} atoms but the model requires {}'.format(n_atoms, self.n_atoms))
-        traj = self._fitter.transform(traj)
+        if self._fitter is not None:
+            traj = self._fitter.transform(traj)
         n_frames = traj.shape[0]
-        return self._pca.transform(traj.reshape((n_frames, -1)))
+        scores = self._pca.transform(traj.reshape((n_frames, -1)))
+        if one_frame:
+            scores = scores[0]
+        return scores
 
     def inverse_transform(self, traj):
         """
@@ -182,11 +197,15 @@ class PCA(object):
         traj = np.array(traj)
         if len(traj.shape) > 2 or traj.shape[-1] != self.n_components:
             raise ValueError('Error: traj must be a vector of length {} or an array of shape [any,{}]'.format(self.n_components, self.n_components))
-        if len(traj.shape) == 1:
+        one_frame = len(traj.shape) == 1
+        if one_frame:
             traj = traj.reshape((1, -1) )
         n_frames = len(traj)
         crds = self._pca.inverse_transform(traj)
-        return crds.reshape((n_frames, self.n_atoms, 3))
+        crds = crds.reshape((n_frames, self.n_atoms, 3))
+        if one_frame:
+            crds = crds[0]
+        return crds
         
     def fit_transform(self, traj):
         """
