@@ -1,4 +1,3 @@
-import mdtraj as mdt
 import os
 import numpy as np
 import pytest
@@ -6,20 +5,12 @@ from mdplus import pca
 from mdplus.utils import rmsd
 
 rootdir = os.path.dirname(os.path.abspath('__file__'))
-ncfile = os.path.join(rootdir, 'test/examples/test.nc')
-pdbfile = os.path.join(rootdir, 'test/examples/test.pdb')
-pczfile = os.path.join(rootdir, 'test/examples/test.pcz')
-pczfile_dm = os.path.join(rootdir, 'test/examples/test_dm.pcz')
+trajfile = os.path.join(rootdir, 'examples/test_ca.npy')
 
 @pytest.fixture(scope="module")
 def traj():
-    t =  mdt.load(ncfile, top=pdbfile)
-    return t.atom_slice(t.topology.select('name CA')).xyz
-
-@pytest.fixture(scope="module")
-def smalltraj():
-    t = mdt.load(ncfile, top=pdbfile)
-    return t.atom_slice(t.topology.select('residue 1')).xyz
+    t =  np.load(trajfile)
+    return t
 
 def test_fit(traj):
     p = pca.PCA(n_components=0.9)
@@ -41,3 +32,10 @@ def test_fit_transform_inverse_transform(traj):
     for i in range(len(newxyz)):
         assert rmsd(traj[i],  newxyz[i]) < 0.02
 
+def test_fit_transform_nofit(traj):
+    p = pca.PCA(n_components=0.9, procrustes=False)
+    projs = p.fit_transform(traj)
+    assert p.n_atoms == 58
+    assert p.n_components == 6
+    assert projs.shape[1] == p.n_components
+
